@@ -6,7 +6,7 @@ extern "C" {
 #endif
 
 /* gifx.h - Functions to turn GIFs in memory into X Pixmaps.
-   Copyright (C) 1997-2013 Eddie Kohler, ekohler@gmail.com
+   Copyright (C) 1997-2014 Eddie Kohler, ekohler@gmail.com
    This file is part of the LCDF GIF library.
 
    The LCDF GIF library is free software*. It is distributed under the GNU
@@ -62,11 +62,12 @@ Pixmap		Gif_XImageColormap(Gif_XContext *gfx, Gif_Stream *gfs,
 				Gif_Colormap *gfcm, Gif_Image *gfi);
 Pixmap		Gif_XSubImage(Gif_XContext *gfx, Gif_Stream *gfs,
 				Gif_Image *gfi, int l, int t, int w, int h);
-Pixmap		Gif_XSubImageColormap(Gif_XContext *gfx, Gif_Image *gfi,
-				Gif_Colormap *gfcm, int l, int t, int w, int h);
+Pixmap		Gif_XSubImageColormap(Gif_XContext *gfx,
+                                Gif_Stream* gfs, Gif_Image *gfi,
+				Gif_Colormap* gfcm, int l, int t, int w, int h);
 
 Pixmap		Gif_XMask(Gif_XContext *gfx, Gif_Stream *gfs, Gif_Image *gfi);
-Pixmap		Gif_XSubMask(Gif_XContext *gfx, Gif_Image *gfi,
+Pixmap		Gif_XSubMask(Gif_XContext* gfx, Gif_Stream* gfs, Gif_Image* gfi,
 				int l, int t, int w, int h);
 
 Gif_XFrame *	Gif_NewXFrames(Gif_Stream *gfs);
