@@ -18,15 +18,23 @@
 # include <unistd.h>
 #endif
 
-#define QUIET_OPT		300
-#define HELP_OPT		301
-#define VERSION_OPT		302
-#define IGNORE_REDUNDANCY_OPT	303
+#define QUIET_OPT               300
+#define HELP_OPT                301
+#define VERSION_OPT             302
+#define IGNORE_REDUNDANCY_OPT   303
+#define REDUNDANCY_OPT          304
+#define IGNORE_BACKGROUND_OPT   305
+#define BACKGROUND_OPT          306
 
 const Clp_Option options[] = {
   { "help", 'h', HELP_OPT, 0, 0 },
   { "brief", 'q', QUIET_OPT, 0, Clp_Negate },
+  { "redudancy", 0, REDUNDANCY_OPT, 0, Clp_Negate },
   { "ignore-redundancy", 'w', IGNORE_REDUNDANCY_OPT, 0, Clp_Negate },
+  { "bg", 0, BACKGROUND_OPT, 0, Clp_Negate },
+  { "ignore-bg", 0, IGNORE_BACKGROUND_OPT, 0, Clp_Negate },
+  { "background", 0, BACKGROUND_OPT, 0, Clp_Negate },
+  { "ignore-background", 'B', IGNORE_BACKGROUND_OPT, 0, Clp_Negate },
   { "version", 'v', VERSION_OPT, 0, 0 }
 };
 
@@ -45,6 +53,7 @@ static uint16_t *line;
 
 static int brief;
 static int ignore_redundancy;
+static int ignore_background;
 
 static Clp_Parser* clp;
 
@@ -145,20 +154,20 @@ apply_image(int is_second, Gif_Stream *gfs, int imageno, uint16_t background)
     for (y = tp; y < bt; ++y) {
       uint16_t *outd = data + screen_width * y + lf;
       if (!any_change)
-	memcpy(line, outd, (rt - lf) * sizeof(uint16_t));
+        memcpy(line, outd, (rt - lf) * sizeof(uint16_t));
       if (pgfi && y >= pgfi->top && y < pgfi->top + pgfi->height)
-	memcpy(outd + pgfi->left - lf,
-	       last + screen_width * y + pgfi->left,
-	       pgfi->width * sizeof(uint16_t));
+        memcpy(outd + pgfi->left - lf,
+               last + screen_width * y + pgfi->left,
+               pgfi->width * sizeof(uint16_t));
       if (y >= gfi->top && y < gfi->top + gfi->height) {
-	uint16_t *xoutd = outd + gfi->left - lf;
-	const uint8_t *ind = gfi->img[y - gfi->top];
-	for (x = 0; x < width; ++x, ++ind, ++xoutd)
-	  if (map[*ind] != TRANSP)
-	    *xoutd = map[*ind];
+        uint16_t *xoutd = outd + gfi->left - lf;
+        const uint8_t *ind = gfi->img[y - gfi->top];
+        for (x = 0; x < width; ++x, ++ind, ++xoutd)
+          if (map[*ind] != TRANSP)
+            *xoutd = map[*ind];
       }
       if (!any_change && memcmp(line, outd, (rt - lf) * sizeof(uint16_t)) != 0)
-	any_change = 1;
+        any_change = 1;
     }
   }
 
@@ -186,8 +195,8 @@ different(const char *format, ...)
   va_list val;
   va_start(val, format);
   if (!brief) {
-    vfprintf(stderr, format, val);
-    fputc('\n', stderr);
+    vfprintf(stdout, format, val);
+    fputc('\n', stdout);
   }
   va_end(val);
   was_different = 1;
@@ -249,7 +258,7 @@ compare(Gif_Stream *s1, Gif_Stream *s2)
   if (s1->screen_width != s2->screen_width
       || s1->screen_height != s2->screen_height) {
     different("screen sizes differ: <%dx%d >%dx%d", s1->screen_width,
-	      s1->screen_height, s2->screen_width, s2->screen_height);
+              s1->screen_height, s2->screen_width, s2->screen_height);
     return DIFFERENT;
   }
 
@@ -282,19 +291,18 @@ compare(Gif_Stream *s1, Gif_Stream *s2)
   for (imageno2 = 0; imageno2 < s2->nimages; ++imageno2)
     combine_colormaps(s2->images[imageno2]->local, newcm);
 
-  /* Choose the background values and clear the image data arrays */
-  if (s1->images[0]->transparent >= 0 || !s1->global)
-    background1 = TRANSP;
-  else
-    background1 = s1->global->col[ s1->background ].pixel;
+  /* Choose the background values */
+  background1 = background2 = TRANSP;
+  if ((s1->nimages == 0 || s1->images[0]->transparent < 0)
+      && s1->global && s1->background < s1->global->ncol)
+      background1 = s1->global->col[ s1->background ].pixel;
+  if ((s2->nimages == 0 || s2->images[0]->transparent < 0)
+      && s2->global && s2->background < s2->global->ncol)
+      background2 = s2->global->col[ s2->background ].pixel;
 
-  if (s2->images[0]->transparent >= 0 || !s2->global)
-    background2 = TRANSP;
-  else
-    background2 = s2->global->col[ s2->background ].pixel;
-
-  fill_area(gdata[0], 0, 0, screen_width, screen_height, background1);
-  fill_area(gdata[1], 0, 0, screen_width, screen_height, background2);
+  /* Clear screens */
+  fill_area(gdata[0], 0, 0, screen_width, screen_height, TRANSP);
+  fill_area(gdata[1], 0, 0, screen_width, screen_height, TRANSP);
 
   /* Loopcounts differ? */
   if (s1->loopcount != s2->loopcount) {
@@ -319,35 +327,52 @@ compare(Gif_Stream *s1, Gif_Stream *s2)
 
     /* compare pixels */
     if (memcmp(gdata[0], gdata[1],
-	       screen_width * screen_height * sizeof(uint16_t)) != 0) {
+               screen_width * screen_height * sizeof(uint16_t)) != 0) {
       unsigned d, c = screen_width * screen_height;
       uint16_t *d1 = gdata[0], *d2 = gdata[1];
       for (d = 0; d < c; d++, d1++, d2++)
-	if (*d1 != *d2) {
-	  name_color(*d1, newcm, buf1);
-	  name_color(*d2, newcm, buf2);
-	  different("frame %s pixels differ: %d,%d <%s >%s",
-		    fbuf, d % screen_width, d / screen_width, buf1, buf2);
-	  break;
-	}
+        if (*d1 != *d2) {
+          name_color(*d1, newcm, buf1);
+          name_color(*d2, newcm, buf2);
+          different("frame %s pixels differ: %d,%d <%s >%s",
+                    fbuf, d % screen_width, d / screen_width, buf1, buf2);
+          break;
+        }
+    }
+
+    /* compare background */
+    if (!ignore_background && background1 != background2
+        && (imageno1 == 0 || s1->images[imageno1 - 1]->disposal == GIF_DISPOSAL_BACKGROUND)
+        && (imageno2 == 0 || s2->images[imageno2 - 1]->disposal == GIF_DISPOSAL_BACKGROUND)) {
+        unsigned d, c = screen_width * screen_height;
+        uint16_t *d1 = gdata[0], *d2 = gdata[1];
+        for (d = 0; d < c; ++d, ++d1, ++d2)
+            if (*d1 == TRANSP || *d2 == TRANSP) {
+                name_color(background1, newcm, buf1);
+                name_color(background2, newcm, buf2);
+                different("frame %s background pixels differ: %d,%d <%s >%s",
+                          fbuf, d % screen_width, d / screen_width, buf1, buf2);
+                background1 = background2 = TRANSP;
+                break;
+            }
     }
 
     /* move to next images, skipping redundancy */
     for (++imageno1;
-	 imageno1 < s1->nimages && !apply_image(0, s1, imageno1, background1);
-	 ++imageno1)
+         imageno1 < s1->nimages && !apply_image(0, s1, imageno1, background1);
+         ++imageno1)
       delay1 += s1->images[imageno1]->delay;
     for (++imageno2;
-	 imageno2 < s2->nimages && !apply_image(1, s2, imageno2, background2);
-	 ++imageno2)
+         imageno2 < s2->nimages && !apply_image(1, s2, imageno2, background2);
+         ++imageno2)
       delay2 += s2->images[imageno2]->delay;
 
     if (!ignore_redundancy) {
       fi1 = (imageno1 - fi1) - (imageno2 - fi2);
       for (; fi1 > 0; --fi1)
-	different("extra redundant frame: <#%d", imageno1 - fi1);
+        different("extra redundant frame: <#%d", imageno1 - fi1);
       for (; fi1 < 0; ++fi1)
-	different("extra redundant frame: >#%d", imageno2 + fi1);
+        different("extra redundant frame: >#%d", imageno2 + fi1);
     }
 
     if (delay1 != delay2) {
@@ -391,6 +416,7 @@ Usage: %s [OPTION]... FILE1 FILE2\n\n", program_name);
 Options:\n\
   -q, --brief                   Don%,t report detailed differences.\n\
   -w, --ignore-redundancy       Ignore differences in redundant frames.\n\
+  -B, --ignore-background       Ignore differences in background colors.\n\
   -h, --help                    Print this message and exit.\n\
   -v, --version                 Print version number and exit.\n\
 \n\
@@ -406,7 +432,7 @@ void fatal_error(const char* format, ...) {
     Clp_vsnprintf(clp, buf + n, BUFSIZ - n, format, val);
     va_end(val);
     fputs(buf, stderr);
-    exit(2);			/* exit(2) for trouble */
+    exit(2);                    /* exit(2) for trouble */
 }
 
 void error(const char* format, ...) {
@@ -444,7 +470,7 @@ gifread_error(Gif_Stream* gfs, Gif_Image* gfi,
   gifread_error_count++;
   if (last_message[0] && different_error_count <= 10
       && (last_which_image != which_image || message == 0
-	  || strcmp(message, last_message) != 0)) {
+          || strcmp(message, last_message) != 0)) {
     const char *etype = last_is_error ? "error" : "warning";
     error("While reading %<%s%> frame #%d:\n", filename, last_which_image);
     if (same_error_count == 1)
@@ -478,33 +504,33 @@ read_stream(const char **filename)
     Gif_Stream *gfs;
     if (*filename == 0) {
 #if 0
-	/* Since gifdiff always takes explicit filename arguments,
-	   allow explicit reads from terminal. */
+        /* Since gifdiff always takes explicit filename arguments,
+           allow explicit reads from terminal. */
 #ifndef OUTPUT_GIF_TO_TERMINAL
-	if (isatty(fileno(stdin))) {
-	    fatal_error("<stdin>: is a terminal\n");
-	    return NULL;
-	}
+        if (isatty(fileno(stdin))) {
+            fatal_error("<stdin>: is a terminal\n");
+            return NULL;
+        }
 #endif
 #endif
-	f = stdin;
+        f = stdin;
 #if defined(_MSDOS) || defined(_WIN32)
-	_setmode(_fileno(stdin), _O_BINARY);
+        _setmode(_fileno(stdin), _O_BINARY);
 #elif defined(__DJGPP__)
-	setmode(fileno(stdin), O_BINARY);
+        setmode(fileno(stdin), O_BINARY);
 #elif defined(__EMX__)
-	_fsetmode(stdin, "b");
+        _fsetmode(stdin, "b");
 #endif
-	*filename = "<stdin>";
+        *filename = "<stdin>";
     } else {
-	f = fopen(*filename, "rb");
-	if (!f)
-	    fatal_error("%s: %s\n", *filename, strerror(errno));
+        f = fopen(*filename, "rb");
+        if (!f)
+            fatal_error("%s: %s\n", *filename, strerror(errno));
     }
     gifread_error_count = 0;
     gfs = Gif_FullReadFile(f, GIF_READ_COMPRESSED, *filename, gifread_error);
     if (!gfs)
-	fatal_error("%s: file not in GIF format\n", *filename);
+        fatal_error("%s: file not in GIF format\n", *filename);
     return gfs;
 }
 
@@ -548,17 +574,29 @@ particular purpose.\n");
       ignore_redundancy = !clp->negated;
       break;
 
+     case REDUNDANCY_OPT:
+      ignore_redundancy = !!clp->negated;
+      break;
+
+     case IGNORE_BACKGROUND_OPT:
+      ignore_background = !clp->negated;
+      break;
+
+     case BACKGROUND_OPT:
+      ignore_background = !!clp->negated;
+      break;
+
      case Clp_NotOption:
       if (how_many_inputs == 2) {
-	error("too many file arguments\n");
-	goto bad_option;
+        error("too many file arguments\n");
+        goto bad_option;
       }
       inputp = (how_many_inputs == 0 ? &filename1 : &filename2);
       how_many_inputs++;
       if (strcmp(clp->vstr, "-") == 0)
-	*inputp = 0;
+        *inputp = 0;
       else
-	*inputp = clp->vstr;
+        *inputp = clp->vstr;
       break;
 
      bad_option:
