@@ -51,6 +51,7 @@ int nested_mode = 0;
 
 static int infoing = 0;
 int verbosing = 0;
+static int no_ignore_errors = 0;
 
 
 #define CHANGED(next, flag)     (((next) & (1<<(flag))) != 0)
@@ -189,6 +190,7 @@ static const char *output_option_types[] = {
 #define RESIZE_COLORS_OPT       371
 #define NO_APP_EXTENSIONS_OPT   372
 #define SAME_APP_EXTENSIONS_OPT 373
+#define IGNORE_ERRORS_OPT       374
 
 #define LOOP_TYPE               (Clp_ValFirstUser)
 #define DISPOSAL_TYPE           (Clp_ValFirstUser + 1)
@@ -249,6 +251,7 @@ const Clp_Option options[] = {
 
   { "help", 'h', HELP_OPT, 0, 0 },
 
+  { "ignore-errors", 0, IGNORE_ERRORS_OPT, 0, Clp_Negate },
   { "info", 'I', INFO_OPT, 0, Clp_Negate },
   { "insert-before", 0, INSERT_OPT, FRAME_SPEC_TYPE, 0 },
   { "interlace", 'i', 'i', 0, Clp_Negate },
@@ -463,7 +466,7 @@ static int gifread_error_count;
 
 static void
 gifread_error(Gif_Stream* gfs, Gif_Image* gfi,
-              int is_error, const char *message)
+              int is_error, const char* message)
 {
   static int last_is_error = 0;
   static char last_landmark[256];
@@ -495,7 +498,9 @@ gifread_error(Gif_Stream* gfs, Gif_Image* gfi,
           || strcmp(landmark, last_landmark) != 0)) {
     const char* etype = last_is_error ? "read error: " : "";
     void (*f)(const char*, const char*, ...) = last_is_error ? lerror : lwarning;
-    if (same_error_count == 1)
+    if (gfi && gfi->user_flags)
+      /* error already reported */;
+    else if (same_error_count == 1)
       f(last_landmark, "%s%s", etype, last_message);
     else if (same_error_count > 0)
       f(last_landmark, "%s%s (%d times)", etype, last_message, same_error_count);
@@ -511,7 +516,8 @@ gifread_error(Gif_Stream* gfs, Gif_Image* gfi,
     strcpy(last_landmark, landmark);
     last_is_error = is_error;
     if (different_error_count == 11) {
-      error(0, "(plus more errors; is this GIF corrupt?)");
+      if (!(gfi && gfi->user_flags))
+        error(0, "(plus more errors; is this GIF corrupt?)");
       different_error_count++;
     }
   } else
@@ -519,13 +525,16 @@ gifread_error(Gif_Stream* gfs, Gif_Image* gfi,
 
   {
     unsigned long missing;
-    if (message && sscanf(message, "missing %lu pixels", &missing) == 1
-        && missing > 10000) {
+    if (message && sscanf(message, "missing %lu pixel", &missing) == 1
+        && missing > 10000 && no_ignore_errors) {
       gifread_error(gfs, 0, -1, 0);
       lerror(landmark, "fatal error: too many missing pixels, giving up");
       exit(1);
     }
   }
+
+  if (gfi && is_error < 0)
+    gfi->user_flags |= 1;
 }
 
 struct StoredFile {
@@ -1919,6 +1928,10 @@ main(int argc, char *argv[])
       no_warnings = clp->negated;
       break;
 
+     case IGNORE_ERRORS_OPT:
+      no_ignore_errors = clp->negated;
+      break;
+
      case CONSERVE_MEMORY_OPT:
       MARK_CH(output, CH_MEMORY);
       def_output_data.conserve_memory = clp->negated ? -1 : 1;
